CyberSize class

Class để định nghĩa size (có thể là số cụ thể hoặc fill parent)

Constructors

CyberSize(double? _value, bool _isFill)
const
CyberSize.fill()
Tạo size fill parent (*)
const
CyberSize.fixed(double value)
Tạo size với giá trị cụ thể
const
CyberSize.wrap()
Tạo size wrap content (null)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isFill bool
no setter
isWrap bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(dynamic input) CyberSize?
Parse từ dynamic (hỗ trợ: số, "*", null)