CyberCamera class

CyberCamera - Camera control có thể add vào màn hình Tap vào preview để chụp ảnh

Inheritance

Constructors

CyberCamera({Key? key, required OnCaptureImage onCapture, OnCameraError? onError, double? height = 300, double borderRadius = 12.0, bool enableCompression = true, int compressionQuality = 85, int? maxWidth = 1920, int? maxHeight = 1920, bool showTapOverlay = true, String? hintText, CameraLensDirection defaultCamera = CameraLensDirection.back})
const

Properties

borderRadius double
Border radius
final
compressionQuality int
Chất lượng nén (0-100)
final
defaultCamera → CameraLensDirection
Camera mặc định (back/front)
final
enableCompression bool
Có nén ảnh hay không
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Chiều cao của camera view
final
hintText String?
Text hướng dẫn
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxHeight int?
Kích thước max sau khi nén (height)
final
maxWidth int?
Kích thước max sau khi nén (width)
final
onCapture OnCaptureImage
Callback khi chụp ảnh thành công
final
onError OnCameraError?
Callback khi có lỗi
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTapOverlay bool
Hiển thị overlay khi tap
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CyberCamera>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited