CyberCameraResult class

Result data sau khi chụp ảnh

Constructors

CyberCameraResult({required File file, required String fileName, required int fileSize, bool isCompressed = false, int? quality})

Properties

file File
final
fileName String
final
fileSize int
final
hashCode int
The hash code for this object.
no setterinherited
isCompressed bool
final
quality int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBase64() Future<String>
Get base64 string
getBytes() Future<List<int>>
Get file as bytes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited