CyberContentViewForm class abstract

Abstract class cho ContentView với lifecycle methods giống CyberForm

Constructors

CyberContentViewForm()

Properties

context BuildContext
no setter
cpName String
no setter
hashCode int
The hash code for this object.
no setterinherited
objectData → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strParameter String
no setter

Methods

buildBody(BuildContext context) Widget
Build nội dung chính của ContentView (REQUIRED)
buildErrorWidget(String error) Widget?
Build error widget (OPTIONAL)
buildLoadingWidget() Widget?
Build loading widget (OPTIONAL)
closePopup<T>(BuildContext context, [T? result]) → void
Close popup với result Usage trong ContentView:
hideLoading() → void
Hide loading dialog
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAfterLoad() Future<void>
  • onAfterLoad - Xử lý sau khi load xong (async)
  • onBeforeLoad() Future<void>
  • onBeforeLoad - Chuẩn bị trước khi load (async)
  • onDispose() → void
  • onDispose - Cleanup (sync)
  • onInit() → void
  • onInit - Khởi tạo cơ bản (sync)
  • onLoadData() Future<void>
  • onLoadData - Load data từ API (async)
  • onLoadError(dynamic error) → void
  • onLoadError - Xử lý lỗi khi load (sync)
  • rebuild() → void
    Rebuild ContentView
    showAsDialog<T>(BuildContext context, {PopupAnimation animation = PopupAnimation.scale, bool barrierDismissible = true, Color? barrierColor, EdgeInsets? margin, EdgeInsets? padding, double? width, double? height, BorderRadius? borderRadius, Color? backgroundColor}) Future<T?>
    Show ContentView as center dialog Usage:
    showBottom<T>(BuildContext context, {PopupAnimation animation = PopupAnimation.slideAndFade, bool barrierDismissible = true, Color? barrierColor, EdgeInsets? margin, EdgeInsets? padding, BorderRadius? borderRadius, Color? backgroundColor}) Future<T?>
    Show ContentView as bottom sheet Usage:
    showLoading([String? message]) → void
    Show loading dialog
    showPopup<T>(BuildContext context, {PopupPosition position = PopupPosition.center, PopupAnimation animation = PopupAnimation.slideAndFade, bool barrierDismissible = true, Color? barrierColor, EdgeInsets? margin, EdgeInsets? padding, double? width, double? height, BorderRadius? borderRadius, Color? backgroundColor}) Future<T?>
    Show ContentView as popup Usage:
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited