CyberFilePicker class
CyberFilePicker - Button để chọn ảnh/file với compression
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CyberFilePicker
Constructors
-
CyberFilePicker({Key? key, String label = "Chọn file", IconData? icon, required OnFileSelected onFileSelected, OnFileError? onError, Color? backgroundColor, Color? textColor, double borderRadius = 8.0, EdgeInsets? padding, bool enabled = true, bool enableCompression = true, int compressionQuality = 85, int? maxWidth = 1920, int? maxHeight = 1920, List<
String> ? allowedExtensions, bool allowMultiple = false, ButtonStyle? buttonStyle}) -
const
Properties
-
allowedExtensions
→ List<
String> ? -
Allowed file extensions cho file picker
final
- allowMultiple → bool
-
Cho phép chọn nhiều file
final
- backgroundColor → Color?
-
Màu nền button
final
- borderRadius → double
-
Border radius
final
-
Style cho button
final
- compressionQuality → int
-
Chất lượng nén (0-100)
final
- enableCompression → bool
-
Có nén ảnh hay không
final
- enabled → bool
-
Có enable hay không
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
Icon button
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
Label hiển thị trên button
final
- maxHeight → int?
-
Kích thước max sau khi nén (height)
final
- maxWidth → int?
-
Kích thước max sau khi nén (width)
final
- onError → OnFileError?
-
Callback khi có lỗi
final
- onFileSelected → OnFileSelected
-
Callback khi chọn file thành công
final
- padding → EdgeInsets?
-
Padding
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
Màu text
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited