CyberFilePickerField class
Helper widget - CyberFilePickerField Hiển thị file đã chọn với preview và button remove
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CyberFilePickerField
Constructors
-
CyberFilePickerField({Key? key, String label = "Chọn file", String? hint, required OnFileSelected onFileSelected, OnFileError? onError, bool enableCompression = true, int compressionQuality = 85, int? maxWidth = 1920, int? maxHeight = 1920, List<
String> ? allowedExtensions, bool isShowLabel = true, Color? backgroundColor}) -
const
Properties
-
allowedExtensions
→ List<
String> ? -
final
- backgroundColor → Color?
-
final
- compressionQuality → int
-
final
- enableCompression → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- isShowLabel → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
final
- maxHeight → int?
-
final
- maxWidth → int?
-
final
- onError → OnFileError?
-
final
- onFileSelected → OnFileSelected
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CyberFilePickerField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited