CyberFileResult class

Result data sau khi chọn file

Constructors

CyberFileResult({required File file, required String fileName, required String extension, required int fileSize, required CyberFileType fileType, bool isCompressed = false})

Properties

extension String
final
file File
final
fileName String
final
fileSize int
final
fileType CyberFileType
final
hashCode int
The hash code for this object.
no setterinherited
isCompressed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBase64() Future<String>
Get base64 string
getBytes() Future<List<int>>
Get file as bytes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited