CyberLabel class

Inheritance

Constructors

CyberLabel({Key? key, dynamic text, String? format, TextStyle? style, TextAlign? textalign, Color? textcolor, Color? backgroundColor, dynamic isVisible = true, bool isIcon = false, double? iconSpacing, double? iconSize, dynamic onLeaver(dynamic)?, bool? showRipple, Color? rippleColor, BorderRadius? rippleBorderRadius, EdgeInsets? tapPadding, int? maxLines, TextOverflow? overflow})
const

Properties

backgroundColor Color?
final
format String?
final
hashCode int
The hash code for this object.
no setterinherited
iconSize double?
final
iconSpacing double?
final
isIcon bool
final
isVisible → dynamic
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines int?
final
onLeaver → dynamic Function(dynamic)?
final
overflow TextOverflow?
final
rippleBorderRadius BorderRadius?
final
rippleColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showRipple bool?
final
style TextStyle?
final
tapPadding EdgeInsets?
final
text → dynamic
final
textalign TextAlign?
final
textcolor Color?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited