CyberMessageBox class

CyberMessageBox - MessageBox với iOS style

Constructors

CyberMessageBox({required String message, String? title, CyberMsgBoxType type = CyberMsgBoxType.defaultType, String? confirmText, String? cancelText})
const

Properties

cancelText String?
final
confirmText String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
type CyberMsgBoxType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) Future<bool>
Show MessageBox và trả về kết quả
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited