CyberMsgBoxType enum

Loại MessageBox

Inheritance
Available extensions

Values

defaultType → const CyberMsgBoxType

Default: Màu xanh iOS, chỉ có nút OK

warning → const CyberMsgBoxType

Warning: Có nút OK và Cancel

error → const CyberMsgBoxType

Error: Màu đỏ destructive, chỉ có nút OK

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CyberMsgBoxType>
A constant List of the values in this enum, in order of their declaration.