CyberRadioItem class
Data class cho mỗi radio item
Constructors
- CyberRadioItem({required dynamic value, required String label, bool enabled = true, Color? activeColor, double? size})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited