CyberRadioGroup class

CyberRadioGroup - Radio button group đơn giản với values và displays

Usage:

CyberRadioGroup(
  text: row.bind("gender"),
  values: "0;1",
  displays: "Nam;Nữ",
  label: "Giới tính",
  group: "gender_group",
)
Inheritance

Constructors

CyberRadioGroup({Key? key, required dynamic text, required dynamic values, required dynamic displays, String? label, required String group, Axis direction = Axis.vertical, double spacing = 8, bool enabled = true, ValueChanged? onChanged, dynamic onLeaver(dynamic)?, Color? activeColor, Color? fillColor, double? size, TextStyle? labelStyle, TextStyle? itemLabelStyle, bool isShowLabel = true, dynamic isVisible = true})
const

Properties

activeColor Color?
Màu khi được chọn
final
direction Axis
Hướng hiển thị: vertical hoặc horizontal
final
displays → dynamic
Danh sách label hiển thị, phân cách bởi ";" - Có thể binding VD: "Nam;Nữ;Khác"
final
enabled bool
Có enable hay không
final
fillColor Color?
Màu của dot bên trong
final
group String
Tên group (unique identifier)
final
hashCode int
The hash code for this object.
no setterinherited
isShowLabel bool
Có hiển thị label group không
final
isVisible → dynamic
Visibility binding
final
itemLabelStyle TextStyle?
Style cho label từng item
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Label cho toàn bộ group
final
labelStyle TextStyle?
Style cho label group
final
onChanged ValueChanged?
Callback khi value thay đổi
final
onLeaver → dynamic Function(dynamic)?
Callback khi rời khỏi control
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
Size của radio button
final
spacing double
Khoảng cách giữa các radio
final
text → dynamic
Binding đến field chứa giá trị được chọn (data binding)
final
values → dynamic
Danh sách giá trị, phân cách bởi ";" - Có thể binding VD: "0;1;2" hoặc "male;female;other"
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CyberRadioGroup>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited