CyberTab class

Model cho mỗi tab trong CyberTabView

Constructors

CyberTab({required String label, required String viewName, String cpName = "", String strParameter = "", dynamic objectData, IconData? icon})
const

Properties

cpName String
final
hashCode int
The hash code for this object.
no setteroverride
icon IconData?
final
label String
final
objectData → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strParameter String
final
viewName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override