didChangeAppLifecycleState method

  1. @override
void didChangeAppLifecycleState(
  1. AppLifecycleState state
)
override

Called when the system puts the app in the background or returns the app to the foreground.

An example of implementing this method is provided in the class-level documentation for the WidgetsBindingObserver class.

This method exposes notifications from SystemChannels.lifecycle.

See also:

Implementation

@override
void didChangeAppLifecycleState(AppLifecycleState state) {
  // Tạm dừng web content khi app ở background để tiết kiệm RAM
  if (_controller != null && !_isDisposed) {
    switch (state) {
      case AppLifecycleState.paused:
      case AppLifecycleState.inactive:
        // WebView tự động pause khi app không active
        break;
      case AppLifecycleState.resumed:
        // WebView tự động resume
        break;
      case AppLifecycleState.detached:
      case AppLifecycleState.hidden:
        break;
    }
  }
}