InternetCheckResult class
Kết quả kiểm tra internet
Constructors
- InternetCheckResult({required bool isValid, required String message, required InternetErrorType errorType, double? speed, bool? isUsingVPN, String? connectionType})
Properties
- connectionType → String?
-
final
- errorType → InternetErrorType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isUsingVPN → bool?
-
final
- isValid → bool
-
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited