CyberBindingExpression class
CyberBindingExpression - đại diện cho expression drEdit'name'
Constructors
- CyberBindingExpression(CyberDataRow row, String fieldName)
Properties
- fieldName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- row → CyberDataRow
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ dynamic
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited