$ class
Operator overload cho CyberDataRow (nếu Dart hỗ trợ) KHÔNG THỂ DÙNG vì Dart không cho override [] trả về type khác CHỈ GHI CHÚ Ý TƯỞNG Class hỗ trợ binding với syntax đơn giản
Constructors
- $()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bind(
CyberDataRow row, String fieldName) → CyberBindingExpression - Tạo binding expression Usage: $Bind(drEdit, 'name')
-
call(
CyberDataRow row, String fieldName) → CyberBindingExpression - Alias ngắn Usage: $(drEdit, 'name')