CyberDataset class

CyberDataset - collection của CyberDataTable với proper disposal

Inheritance

Constructors

CyberDataset()

Properties

hasChanges bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isDisposed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableCount int
no setter
tables Map<String, CyberDataTable>
no setter

Methods

acceptChanges() → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addTable(CyberDataTable table) → void
batch(void action()) → void
beginBatch() → void
✅ NEW: Batch mode control
checkStatus(BuildContext contex, {bool isShowMsg = true}) bool
clear() → void
copy() CyberDataset
createTable(String tableName) CyberDataTable
dispose() → void
Discards any resources used by the object.
override
endBatch() → void
getChangedTables() List<CyberDataTable>
loadFromJson(String jsonString) → void
✅ OPTIMIZED: Batch mode for loading
loadFromMap(Map<String, dynamic> data) → void
loadTable(String tableName, List<Map<String, dynamic>> data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
rejectChanges() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeTable(String tableName) → void
Table(dynamic TableNameOrindex) CyberDataTable?
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override
toXml({List<String>? tableNames, Map<String, List<String>>? tableIncludeColumns, Map<String, List<String>>? tableExcludeColumns}) String

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic tableName) CyberDataTable?