CyberDataTable class

CyberDataTable - collection của CyberDataRow với proper disposal

Inheritance

Constructors

CyberDataTable({required String tableName})

Properties

columns Map<String, Type>
no setter
hasChanges bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isDisposed bool
no setter
rowCount int
no setter
rows List<CyberDataRow>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
final

Methods

acceptChanges() → void
addColumn(String columnName, Type type) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addRow(CyberDataRow row) → void
addRowsBatch(List<CyberDataRow> rows) → void
✅ NEW: Add multiple rows in batch (no notifications until done)
batch(void action()) → void
✅ NEW: Execute action in batch mode
beginBatch() → void
✅ NEW: Batch mode control
clear() → void
✅ OPTIMIZED: Clear with proper disposal
containerColumn(String columnName) bool
copy() CyberDataTable
dispose() → void
Discards any resources used by the object.
override
endBatch() → void
findRow(bool predicate(CyberDataRow)) CyberDataRow?
findRows(bool predicate(CyberDataRow)) List<CyberDataRow>
getChangedRows() List<CyberDataRow>
loadData(List<Map<String, dynamic>> data) → void
✅ OPTIMIZED: Batch mode for better performance
loadDataFromRows(List<CyberDataRow> rows, {bool copy = true}) → void
✅ OPTIMIZED: Batch mode + zero-copy option
loadDatafromTb(CyberDataTable data, {bool copy = true}) → void
✅ OPTIMIZED: Batch mode + smart copying
newRow() CyberDataRow
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
rejectChanges() → void
removeAt(int index) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeRow(CyberDataRow row) → void
toList() List<Map<String, dynamic>>
toString() String
A string representation of this object.
override
toXml({String? tableNameOverride, List<String>? includeColumns, List<String>? excludeColumns}) String

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) CyberDataRow