UserInfo class

Constructors

UserInfo()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

comment String
getter/setter pair
dtCommand CyberDataTable?
getter/setter pair
dtPhanHe CyberDataTable?
getter/setter pair
id_otp String
getter/setter pair
isOTP String
getter/setter pair
ma_dvcs String
getter/setter pair
strTokenId Future<String>
no setter
user_name String
getter/setter pair

Static Methods

logout() Future<void>
✅ Helper method: Clear session
setstrTokenId(String value) Future<void>
V_Login(BuildContext contex, {String userName = "", String password = "", String maDvcs = "", bool isShowMsg = true, bool isShowloading = true}) Future<bool>