CyberLanguageConstants class

Common translated strings

Constructors

CyberLanguageConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

add String
no setter
back String
no setter
cancel String
no setter
close String
no setter
confirm String
no setter
confirmDelete String
no setter
delete String
no setter
deleteSuccess String
no setter
done String
no setter
edit String
no setter
error String
no setter
info String
no setter
loading String
no setter
networkError String
no setter
next String
no setter
noData String
no setter
ok String
no setter
previous String
no setter
retry String
no setter
save String
no setter
saveSuccess String
no setter
no setter
success String
no setter
updateSuccess String
no setter
warning String
no setter