CyberForm class abstract

Implementers

Constructors

CyberForm()

Properties

backgroundColor Color?
no setter
context BuildContext
no setter
cp_name String
no setter
hashCode int
The hash code for this object.
no setterinherited
hideAppBar bool?
no setter
isDisposed bool
✅ Check if form is disposed
no setter
objectdata → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSpeedMonitor bool?
no setter
strparameter String
no setter
title String?
no setter
widget CyberFormView
no setter

Methods

buildBody(BuildContext context) Widget
buildErrorWidget(String error) Widget?
buildLoadingWidget() Widget?
hideLoading() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAfterLoad() Future<void>
onBeforeLoad() Future<void>
onDispose() → void
onInit() → void
onLoadData() Future<void>
onLoadError(dynamic error) → void
rebuild() → void
registerDisposable(dynamic resource) → void
Register resource for automatic disposal
registerListener(Listenable listenable, VoidCallback listener) → void
✅ Register listener with tracking
removeListener(Listenable listenable, VoidCallback listener) → void
✅ Remove specific listener
showLoading([String? message]) → void
toString() String
A string representation of this object.
inherited
V_Call(String strfrm, {bool hideAppBar = false, String title = "", String cpName = "", String strparameter = "", dynamic objectdata}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited