FileData class
✅ IMPROVED: FileData with cleanup capability
Constructors
- FileData({required Uint8List bytes, required String path, required FileSourceType sourceType, bool isTemp = false})
Properties
- bytes → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTemp → bool
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceType → FileSourceType
-
final
Methods
-
cleanup(
) → Future< void> - ✅ Clean up temp file
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited