PhoneHandler class

Constructors

PhoneHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

makePhoneCall(String phoneNumber, {BuildContext? context, bool showConfirmation = false}) Future<bool>
Gọi điện thoại trực tiếp
makeZaloCall(String phoneNumber, {BuildContext? context, bool showConfirmation = false}) Future<bool>
Gọi điện qua Zalo
openContacts({BuildContext? context}) Future<bool>
Mở ứng dụng Danh bạ
openTelegram(String phoneNumber, {BuildContext? context}) Future<bool>
Telegram chat
openViber(String phoneNumber, {BuildContext? context}) Future<bool>
Viber chat
openWhatsApp(String phoneNumber, {String? message, BuildContext? context}) Future<bool>
WhatsApp chat
openZaloChat(String phoneNumber, {BuildContext? context}) Future<bool>
Mở Zalo chat
openZaloOA(String oaId, {BuildContext? context}) Future<bool>
Zalo OA (Official Account) - Mở trang Zalo OA
saveToContacts(String phoneNumber, {String? name, String? email, BuildContext? context}) Future<bool>
Lưu số vào danh bạ (mở form thêm contact mới)
sendSMS(String phoneNumber, {String? message, BuildContext? context}) Future<bool>
Gửi SMS
sendZaloMessage(String phoneNumber, {String? message, BuildContext? context}) Future<bool>
Gửi tin nhắn Zalo (mở chat)