Frmwebview class

Inheritance

Constructors

Frmwebview()

Properties

backgroundColor Color?
no setteroverride
context BuildContext
no setterinherited
cp_name String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hideAppBar bool?
no setteroverride
isDisposed bool
✅ Check if form is disposed
no setterinherited
objectdata → dynamic
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSpeedMonitor bool?
no setterinherited
strparameter String
no setterinherited
title String?
no setteroverride
Url String?
getter/setter pair
widget CyberFormView
no setterinherited

Methods

buildBody(BuildContext context) Widget
override
buildErrorWidget(String error) Widget?
inherited
buildLoadingWidget() Widget?
inherited
clearWebViewCache() Future<void>
goBack() Future<void>
goForward() Future<void>
hideLoading() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAfterLoad() Future<void>
inherited
onBeforeLoad() Future<void>
inherited
onDispose() → void
override
onInit() → void
inherited
onLoadData() Future<void>
inherited
onLoadError(dynamic error) → void
inherited
rebuild() → void
inherited
refreshWebView() Future<void>
registerDisposable(dynamic resource) → void
Register resource for automatic disposal
inherited
registerListener(Listenable listenable, VoidCallback listener) → void
✅ Register listener with tracking
inherited
removeListener(Listenable listenable, VoidCallback listener) → void
✅ Remove specific listener
inherited
showLoading([String? message]) → void
inherited
toString() String
A string representation of this object.
inherited
V_Call(String strfrm, {bool hideAppBar = false, String title = "", String cpName = "", String strparameter = "", dynamic objectdata}) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited