CyberBox class
CyberBox - Container linh hoạt với nhiều children
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CyberBox
- Available extensions
Constructors
-
CyberBox({Key? key, dynamic width, dynamic height, Color? backgroundColor, EdgeInsets? padding, BoxBorder? border, BorderRadius? borderRadius, double? radius, double? topLeftRadius, double? topRightRadius, double? bottomLeftRadius, double? bottomRightRadius, List<
Widget> children = const [], CyberAlign vAlign = CyberAlign.start, CyberAlign hAlign = CyberAlign.start, VoidCallback? onClick, double spacing = 0, bool showRipple = true, EdgeInsets? margin, List<BoxShadow> ? shadows}) -
const
Properties
- backgroundColor → Color?
-
Màu nền
final
- border → BoxBorder?
-
Border
final
- borderRadius → BorderRadius?
-
Bo góc border (ưu tiên dùng nếu có cả radius)
final
- bottomLeftRadius → double?
-
final
- bottomRightRadius → double?
-
final
-
children
→ List<
Widget> -
Danh sách các widget con
final
- hAlign → CyberAlign
-
Căn chỉnh theo chiều ngang (start, center, end)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → dynamic
-
Chiều cao (số cụ thể, "*" để fill, null để wrap content)
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsets?
-
Margin bên ngoài
final
- onClick → VoidCallback?
-
Callback khi click
final
- padding → EdgeInsets?
-
Padding bên trong
final
- radius → double?
-
Bo góc đơn giản (áp dụng đều cho 4 góc)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadows
→ List<
BoxShadow> ? -
Shadow (box shadow)
final
- showRipple → bool
-
Có hiển thị hiệu ứng ripple khi click không
final
- spacing → double
-
Khoảng cách giữa các children
final
- topLeftRadius → double?
-
Bo góc từng góc riêng biệt
final
- topRightRadius → double?
-
final
- vAlign → CyberAlign
-
Căn chỉnh theo chiều dọc (start, center, end)
final
- width → dynamic
-
Chiều rộng (số cụ thể, "*" để fill, null để wrap content)
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited