CyberCameraView class

CyberCameraView - Màn hình camera full screen Show như popup, chụp xong tự động đóng và trả về data

Constructors

CyberCameraView({required BuildContext context, bool enableCompression = true, int compressionQuality = 85, int? maxWidth = 1920, int? maxHeight = 1920, String? title, CameraLensDirection defaultCamera = CameraLensDirection.back, OnCameraError? onError})

Properties

compressionQuality int
final
context BuildContext
final
defaultCamera → CameraLensDirection
final
enableCompression bool
final
hashCode int
The hash code for this object.
no setterinherited
maxHeight int?
final
maxWidth int?
final
onError OnCameraError?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() Future<CyberCameraResult?>
Show camera screen và trả về result
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited