CyberComboBox class

Inheritance

Constructors

CyberComboBox({Key? key, dynamic text, dynamic displayMember, dynamic valueMember, CyberDataTable? dataSource, String? label, String? hint, TextStyle? labelStyle, TextStyle? textStyle, IconData? icon, bool enabled = true, ValueChanged? onChanged, dynamic onLeaver(dynamic)?, Color? iconColor, Color? backgroundColor, Color? borderColor, bool isShowLabel = true, dynamic isVisible = true, dynamic isCheckEmpty = false})
const

Properties

backgroundColor Color?
Background color
final
borderColor Color?
Border color
final
dataSource CyberDataTable?
DataSource là CyberDataTable
final
displayMember → dynamic
Field name để hiển thị (có thể binding)
final
enabled bool
Có enable hay không
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
Hint text khi chưa chọn
final
icon IconData?
Icon
final
iconColor Color?
Màu icon
final
isCheckEmpty → dynamic
final
isShowLabel bool
Show label hay không
final
isVisible → dynamic
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Label hiển thị phía trên
final
labelStyle TextStyle?
Style cho label
final
onChanged ValueChanged?
Callback khi value thay đổi
final
onLeaver → dynamic Function(dynamic)?
Callback khi rời khỏi control
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text → dynamic
Binding đến field chứa giá trị được chọn (value binding)
final
textStyle TextStyle?
Style cho text được chọn
final
valueMember → dynamic
Field name cho giá trị (có thể binding)
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CyberComboBox>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited