CyberContentView class
Legacy CyberContentView class cho popup (giữ lại để backward compatible)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CyberContentView
Constructors
- CyberContentView({Key? key, required Widget child, PopupPosition position = PopupPosition.center, PopupAnimation animation = PopupAnimation.slideAndFade, bool barrierDismissible = true, Color? barrierColor, EdgeInsets? margin, EdgeInsets? padding, double? width, double? height, BorderRadius? borderRadius, Color? backgroundColor, BoxShadow? boxShadow, Duration transitionDuration = const Duration(milliseconds: 300), bool isScrollControlled = true, dynamic onClose(dynamic)?, dynamic onShow()?, dynamic onBeforeShow()?, dynamic onAfterClose(dynamic)?})
-
const
Properties
- animation → PopupAnimation
-
final
- backgroundColor → Color?
-
final
- barrierColor → Color?
-
final
- barrierDismissible → bool
-
final
- borderRadius → BorderRadius?
-
final
- boxShadow → BoxShadow?
-
final
- child → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- isScrollControlled → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsets?
-
final
- onAfterClose → dynamic Function(dynamic)?
-
final
- onBeforeShow → dynamic Function()?
-
final
- onClose → dynamic Function(dynamic)?
-
final
- onShow → dynamic Function()?
-
final
- padding → EdgeInsets?
-
final
- position → PopupPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionDuration → Duration
-
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show<
T> (BuildContext context) → Future< T?> -
showBottom<
T> (BuildContext context) → Future< T?> -
showWith<
T> (BuildContext context, {PopupPosition? position, PopupAnimation? animation, bool? barrierDismissible}) → Future< T?> -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited