CyberGridRow class
Model cho mỗi row trong CyberGrid
Constructors
-
CyberGridRow({required String widthColumns, required List<
Widget> children, EdgeInsets? padding, EdgeInsets? margin, Color? backgroundColor, bool enableHorizontalScroll = false}) -
const
Properties
- backgroundColor → Color?
-
Màu nền của row
final
-
children
→ List<
Widget> -
Danh sách các widget con
final
- enableHorizontalScroll → bool
-
Có cho phép scroll ngang nếu nội dung tràn không
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- margin → EdgeInsets?
-
Margin bên ngoài row
final
- padding → EdgeInsets?
-
Padding bên trong row
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widthColumns → String
-
Khai báo chiều rộng các columns (VD: ";Auto;100;2")
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited