CyberLookup class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CyberLookup
Constructors
- CyberLookup({Key? key, dynamic text, dynamic display, dynamic tbName, dynamic strFilter, dynamic displayField, dynamic displayValue, String? label, String? hint, TextStyle? labelStyle, TextStyle? textStyle, IconData? icon, bool enabled = true, bool readOnly = false, bool allowClear = true, dynamic onLeaver(dynamic)?, ValueChanged? onChanged, Color? backgroundColor, Color? borderColor, bool isShowLabel = true, dynamic isVisible = true, dynamic isCheckEmpty = false, int lookupPageSize = 50})
-
const
Properties
- allowClear → bool
-
✅ NEW: Allow clear button
final
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- display → dynamic
-
final
- displayField → dynamic
-
final
- displayValue → dynamic
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- icon → IconData?
-
final
- isCheckEmpty → dynamic
-
final
- isShowLabel → bool
-
final
- isVisible → dynamic
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- labelStyle → TextStyle?
-
final
- lookupPageSize → int
-
final
- onChanged → ValueChanged?
-
final
- onLeaver → dynamic Function(dynamic)?
-
final
- readOnly → bool
-
✅ NEW: Read-only mode
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strFilter → dynamic
-
final
- tbName → dynamic
-
final
- text → dynamic
-
final
- textStyle → TextStyle?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CyberLookup> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited