CyberPopup class
Constructors
- CyberPopup({required BuildContext context, required Widget child, PopupPosition position = PopupPosition.center, PopupAnimation animation = PopupAnimation.slideAndFade, bool barrierDismissible = true, Color? barrierColor, EdgeInsets? margin, EdgeInsets? padding, double? width, double? height, BorderRadius? borderRadius, Color? backgroundColor, BoxShadow? boxShadow, dynamic onClose(dynamic)?, dynamic onShow()?, Duration transitionDuration = const Duration(milliseconds: 300), bool isScrollControlled = true})
Properties
- animation → PopupAnimation
-
final
- backgroundColor → Color?
-
final
- barrierColor → Color?
-
final
- barrierDismissible → bool
-
final
- borderRadius → BorderRadius?
-
final
- boxShadow → BoxShadow?
-
final
- child → Widget
-
final
- context → BuildContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- isScrollControlled → bool
-
final
- margin → EdgeInsets?
-
final
- onClose → dynamic Function(dynamic)?
-
final
- onShow → dynamic Function()?
-
final
- padding → EdgeInsets?
-
final
- position → PopupPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionDuration → Duration
-
final
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show<
T> () → Future< T?> -
showBotton<
T> () → Future< T?> -
showFullScreen<
T> () → Future< T?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
close<
T> (BuildContext context, [T? result]) → void