CyberRadioBox class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CyberRadioBox
Constructors
- CyberRadioBox({Key? key, required dynamic text, required dynamic group, required dynamic value, String? label, TextStyle? labelStyle, bool enabled = true, dynamic isVisible = true, ValueChanged? onChanged, dynamic onLeaver(dynamic)?, Color? activeColor, Color? fillColor, double? size})
-
const
Properties
- activeColor → Color?
-
Màu khi được chọn
final
- enabled → bool
-
Có enable hay không
final
- fillColor → Color?
-
Màu của dot bên trong
final
- group → dynamic
-
Tên nhóm để group các radio buttons với nhau (có thể binding)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isVisible → dynamic
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Label hiển thị bên cạnh radio
final
- labelStyle → TextStyle?
-
Style cho label
final
- onChanged → ValueChanged?
-
Callback khi value thay đổi
final
- onLeaver → dynamic Function(dynamic)?
-
Callback khi rời khỏi control
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double?
-
Size của radio button
final
- text → dynamic
-
Binding đến field chứa giá trị được chọn (data binding)
final
- value → dynamic
-
Giá trị của radio này (khi được chọn, text sẽ = value) (có thể binding)
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CyberRadioBox> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited