CyberTabView class
TabView với lazy loading, proper disposal, và optimized rendering
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CyberTabView
Constructors
-
CyberTabView({Key? key, required List<
CyberTab> tabs, int initialIndex = 0, Color? backColorTab, Color? textColorTab, Color? selectBackColorTab, Color? selectTextColorTab, Color? indicatorColor, double? tabBarHeight, bool isScrollable = true, bool keepAlive = false, dynamic onTabChanged(int index)?, TabBarIndicatorSize? indicatorSize, EdgeInsets? labelPadding, EdgeInsets? indicatorPadding, Decoration? indicator, bool enableFeedback = true, BorderRadius? tabBorderRadius, double? tabSpacing}) -
const
Properties
- backColorTab → Color?
-
final
- enableFeedback → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicator → Decoration?
-
final
- indicatorColor → Color?
-
final
- indicatorPadding → EdgeInsets?
-
final
- indicatorSize → TabBarIndicatorSize?
-
final
- initialIndex → int
-
final
- isScrollable → bool
-
final
- keepAlive → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelPadding → EdgeInsets?
-
final
- onTabChanged → dynamic Function(int index)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectBackColorTab → Color?
-
final
- selectTextColorTab → Color?
-
final
- tabBarHeight → double?
-
final
- tabBorderRadius → BorderRadius?
-
final
-
tabs
→ List<
CyberTab> -
final
- tabSpacing → double?
-
final
- textColorTab → Color?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CyberTabView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited