ReturnData class
Constructors
-
ReturnData({bool? status, String? message, dynamic data, List<
int> ? noRow, bool? isConnect, dynamic cyberObject}) -
ReturnData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cyberObject ↔ dynamic
-
getter/setter pair
- data ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnect ↔ bool?
-
getter/setter pair
- message ↔ String?
-
getter/setter pair
-
noRow
↔ List<
int> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ bool?
-
getter/setter pair
Methods
-
isValid(
) → bool - ✅ Check if response is valid
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCyberDataset(
) → CyberDataset? - ✅ Convert data to CyberDataset with lowercase keys
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited